#ifndef __BROADCAST_FIELDS_H__
#define __BROADCAST_FIELDS_H__

namespace FactSet {
    namespace Datafeed {

        struct BroadcastFieldType {
            // Brackets will suppress doxygen undocumented warnings
            //! \{
            static const int BUFFER = 14;
            static const int CHAR = 1;
            static const int DOUBLE = 5;
            static const int EPOCH_NSEC = 22;
            static const int FLOAT = 4;
            static const int INT = 2;
            static const int INT64 = 19;
            static const int RAW = 0;
            static const int STRING = 6;
            //! \}
        };

        struct BroadcastFieldId {
            // Brackets will suppress doxygen undocumented warnings
            //! \{
            static const int FDS_SEQ_NUM = 1; // INT
            static const int PRODUCT = 4; // INT
            static const int DESCRIPTION = 8; // STRING
            static const int ISIN = 12; // STRING
            static const int FEED_ID = 13; // INT
            static const int CUSIP = 14; // STRING
            static const int SEDOL = 15; // STRING
            static const int ISO_CODE = 17; // STRING
            static const int EXCHANGE = 20; // INT
            static const int MSG_BITMASK = 22; // INT
            static const int LAST_TICK = 25; // INT
            static const int EPS = 28; // FLOAT
            static const int SHARES_OUTSTANDING = 29; // FLOAT
            static const int LAST_VOL = 31; // INT
            static const int LAST_EXCH = 33; // INT
            static const int QUOTE_CONDITION = 38; // INT
            static const int LAST_PRICE = 50; // DOUBLE
            static const int CONTRACT_SIZE = 51; // INT
            static const int PRICE_CURRENCY = 62; // STRING
            static const int PAYMENT_DATE = 76; // INT
            static const int RECORD_DATE = 77; // INT
            static const int MARKET_MECHANISM_TYPE = 88; // STRING
            static const int ORDER_CODE = 89; // STRING
            static const int HIGH_VOL = 105; // INT
            static const int HIGH = 107; // DOUBLE
            static const int CVOL = 132; // INT64
            static const int TOTAL_CAP_GAIN = 147; // DOUBLE
            static const int FOOTNOTE = 148; // STRING
            static const int OPEN = 158; // DOUBLE
            static const int TRADE_CONDITION = 174; // STRING
            static const int CONTRACT_HIGH = 189; // DOUBLE
            static const int PREV_CLOSE = 208; // DOUBLE
            static const int CONTRACT_LOW = 209; // DOUBLE
            static const int STRIKE_PRICE = 239; // DOUBLE
            static const int TRADE_COUNT = 267; // INT
            static const int BLOCK_TRADE_COUNT = 269; // INT
            static const int BLOCK_CVOL = 271; // INT
            static const int SHORT_SALE_INDICATOR = 277; // INT
            static const int MID = 278; // DOUBLE
            static const int ANNUALIZED_SEVEN_DAY_YIELD = 279; // DOUBLE
            static const int BID_CLOSE_VOL = 296; // INT
            static const int ASK_CLOSE_VOL = 297; // INT
            static const int LOW_VOL = 305; // INT
            static const int LOW = 307; // DOUBLE
            static const int TURNOVER = 341; // DOUBLE
            static const int MID_NET_CHANGE = 342; // DOUBLE
            static const int BID_POINTS = 343; // DOUBLE
            static const int GMT_OFFSET = 389; // INT
            static const int DAYS_TO_EXPIRATION = 390; // INT
            static const int MID_HIGH = 398; // DOUBLE
            static const int MID_LOW = 399; // DOUBLE
            static const int ORDER_LOT_SIZE = 427; // INT
            static const int UNCROSSING_PRICE = 465; // DOUBLE
            static const int UNCROSSING_VOL = 466; // INT
            static const int BID_VOL = 505; // INT
            static const int BID_EXCH = 506; // INT
            static const int BID = 509; // DOUBLE
            static const int BID_TICK = 518; // INT
            static const int OFFICIAL_CLOSE = 526; // DOUBLE
            static const int OFFBOOK_CUM_VOL = 528; // INT
            static const int VENUE = 530; // STRING
            static const int EX_DATE_STATUS = 531; // STRING
            static const int MID_CLOSE = 535; // DOUBLE
            static const int SPREAD_10Y = 537; // DOUBLE
            static const int SPREAD_5Y = 538; // DOUBLE
            static const int ASK_YIELD = 541; // DOUBLE
            static const int BENCHMARK_ID = 546; // STRING
            static const int BID_YIELD = 550; // DOUBLE
            static const int CALLABLE_DATE = 552; // INT
            static const int COUPON_RATE = 556; // DOUBLE
            static const int MID_YIELD = 571; // DOUBLE
            static const int HIGH_YIELD = 573; // DOUBLE
            static const int ISSUE_DATE = 574; // INT
            static const int ASK_VOL = 605; // INT
            static const int ASK_EXCH = 606; // INT
            static const int ASK = 609; // DOUBLE
            static const int NORMAL_MARKET_SIZE = 629; // INT
            static const int STANDARD_MARKET_SIZE = 630; // INT
            static const int EXCHANGE_MARKET_SIZE = 631; // INT
            static const int SETTLEMENT_INDICATOR = 632; // INT
            static const int PERIOD = 633; // STRING
            static const int AUTO_TRADE_CVOL = 635; // INT
            static const int AUTO_TRADE_COUNT = 636; // INT
            static const int AUTO_TRADE_VWAP = 637; // DOUBLE
            static const int TOTAL_BUY_VOL = 640; // INT
            static const int TOTAL_SELL_VOL = 641; // INT
            static const int BUY_PERCENTAGE = 642; // DOUBLE
            static const int SELL_PERCENTAGE = 643; // DOUBLE
            static const int BID_CLOSE = 648; // DOUBLE
            static const int ASK_CLOSE = 649; // DOUBLE
            static const int MARKET_SEGMENT = 650; // STRING
            static const int MARKET_SECTOR = 651; // STRING
            static const int COUNTRY_CODE = 652; // STRING
            static const int ASSETS_PRICE = 654; // DOUBLE
            static const int CURRENT_YIELD = 656; // DOUBLE
            static const int DIVIDEND_PRICE = 657; // DOUBLE
            static const int LONG_CAP_GAIN = 659; // DOUBLE
            static const int NET_CHANGE = 662; // DOUBLE
            static const int OTHER_CAP_GAIN = 663; // DOUBLE
            static const int SEVEN_DAY_YIELD = 666; // DOUBLE
            static const int SHORT_CAP_GAIN = 667; // DOUBLE
            static const int UNALLOC_DISTR_PRICE = 668; // DOUBLE
            static const int RETURN_1D = 671; // DOUBLE
            static const int RETURN_YTD = 672; // DOUBLE
            static const int RETURN_1M = 673; // DOUBLE
            static const int RETURN_3M = 674; // DOUBLE
            static const int RETURN_12M = 675; // DOUBLE
            static const int RETURN_MTD = 676; // DOUBLE
            static const int RETURN_QTD = 677; // DOUBLE
            static const int RETURN_WTD = 678; // DOUBLE
            static const int COMMISSION = 703; // STRING
            static const int SPECIAL_PRICE_INDICATOR = 704; // STRING
            static const int VOLUME_INDICATOR = 705; // STRING
            static const int ASK_POINTS = 706; // DOUBLE
            static const int AVG_30DAY_VOL = 709; // FLOAT
            static const int OPEN_INTEREST = 711; // INT
            static const int EXPIRATION_DATE = 713; // INT
            static const int DIVIDEND = 714; // FLOAT
            static const int AVG_5DAY_VOL = 719; // FLOAT
            static const int FACTSET_INDUSTRY = 722; // STRING
            static const int FACTSET_SECTOR = 723; // STRING
            static const int HOMEPAGE = 724; // STRING
            static const int DIVIDEND_YIELD = 736; // FLOAT
            static const int DOLLAR_CHANGE = 764; // DOUBLE
            static const int CLOSE_2 = 766; // DOUBLE
            static const int HIGH_52WEEK = 767; // DOUBLE
            static const int LOW_52WEEK = 768; // DOUBLE
            static const int OPEN_2 = 771; // DOUBLE
            static const int RESUME = 772; // DOUBLE
            static const int RESUME_2 = 773; // DOUBLE
            static const int PREV_SETTLE = 775; // DOUBLE
            static const int VWAP = 780; // DOUBLE
            static const int SETTLEMENT_TODAY = 781; // DOUBLE
            static const int SETTLEMENT_DATE = 793; // INT
            static const int CLOSE_YIELD = 798; // DOUBLE
            static const int LOW_YIELD = 799; // DOUBLE
            static const int PREV_SETTLE_DATE = 805; // INT
            static const int SETTLEMENT = 815; // DOUBLE
            static const int PERCENT_CHANGE = 816; // DOUBLE
            static const int CORR_LAST_VOL = 834; // INT
            static const int AS_OF_INDICATOR = 890; // INT
            static const int PREV_CLOSE_UNADJ = 892; // DOUBLE
            static const int SELLER_DAYS = 895; // INT
            static const int PREMKT_NET_CHANGE = 896; // DOUBLE
            static const int PREMKT_PERCENT_CHANGE = 897; // DOUBLE
            static const int TRADED_PRICE = 912; // DOUBLE
            static const int TRADED_VOL = 918; // INT
            static const int REPORTING_SIDE = 924; // STRING
            static const int SEQUENCE = 1000; // INT
            static const int ORIG_SEQUENCE = 1001; // INT
            static const int INSTRUMENT_ID = 1002; // INT64
            static const int VENDOR_SYMBOL = 1010; // STRING
            static const int UNDERLYING_SECURITY = 1011; // STRING
            static const int PREMKT_PRICE = 1019; // DOUBLE
            static const int MSG_TYPE = 1030; // INT
            static const int UPPER_TRADING_BAND = 1087; // DOUBLE
            static const int LOWER_TRADING_BAND = 1093; // DOUBLE
            static const int TRADED_CONDITION = 1098; // STRING
            static const int UNCROSSING_CONDITION = 1104; // INT
            static const int SETTLEMENT_TIME = 1160; // INT
            static const int SETTLEMENT_DATE_TODAY = 1162; // INT
            static const int PREV_CLOSE_2 = 1172; // DOUBLE
            static const int PREV_CLOSE_UNADJ_2 = 1176; // DOUBLE
            static const int FEED_CURRENCY = 1182; // STRING
            static const int HALT_DESCRIPTION = 1184; // STRING
            static const int COUNTRY_NAME = 1190; // STRING
            static const int CORR_LAST = 1199; // DOUBLE
            static const int HIGH_52WEEK_DATE = 1220; // INT
            static const int UNOFFICIAL_PRICE = 1288; // DOUBLE
            static const int UNOFFICIAL_VOLUME = 1292; // INT
            static const int LOW_52WEEK_DATE = 1295; // INT
            static const int UNOFFICIAL_CONDITION = 1334; // STRING
            static const int TRADE_LOT_SIZE = 1335; // INT
            static const int BENCHMARK_YIELD = 1369; // DOUBLE
            static const int BENCHMARK_YIELD_BID = 1373; // DOUBLE
            static const int BENCHMARK_YIELD_ASK = 1377; // DOUBLE
            static const int BENCHMARK_SPREAD = 1381; // DOUBLE
            static const int BENCHMARK_SPREAD_BID = 1385; // DOUBLE
            static const int BENCHMARK_SPREAD_ASK = 1389; // DOUBLE
            static const int TRADED_YIELD = 1394; // DOUBLE
            static const int MSG_GENESIS = 1409; // INT64
            static const int HALT_INFO = 1414; // INT
            static const int FIRST_SESSION_PRICE = 1438; // DOUBLE
            static const int FIRST_SESSION_HIGH = 1442; // DOUBLE
            static const int FIRST_SESSION_LOW = 1446; // DOUBLE
            static const int FIRST_SESSION_CLOSE = 1450; // DOUBLE
            static const int FIRST_SESSION_CVOL = 1454; // INT64
            static const int FIRST_SESSION_VWAP = 1455; // DOUBLE
            static const int SECOND_SESSION_PRICE = 1459; // DOUBLE
            static const int SECOND_SESSION_HIGH = 1463; // DOUBLE
            static const int SECOND_SESSION_LOW = 1467; // DOUBLE
            static const int SECOND_SESSION_CLOSE = 1471; // DOUBLE
            static const int SECOND_SESSION_CVOL = 1475; // INT64
            static const int SECOND_SESSION_VWAP = 1476; // DOUBLE
            static const int TICK_SIZE = 1499; // DOUBLE
            static const int TICK_GROUP = 1507; // STRING
            static const int TICK_PILOT_EFF_DATE = 1508; // INT
            static const int PRICE_MULTIPLIER = 1509; // DOUBLE
            static const int NOMINAL_VALUE = 1513; // DOUBLE
            static const int PRIMARY_MARKET = 1517; // STRING
            static const int SECOND_SESSION_OPEN = 1528; // DOUBLE
            static const int EXECUTION_VENUE = 1579; // STRING
            static const int NOTIONAL_AMOUNT = 1591; // DOUBLE
            static const int NOTIONAL_CURRENCY = 1595; // STRING
            static const int PRICE_NOTATION = 1596; // STRING
            static const int QUANTITY_NOTATION = 1597; // STRING
            static const int TRANSPARENCY_INDICATOR = 1598; // INT
            static const int MIFID_CLEARING_FLAG = 1599; // INT
            static const int MIC_CODE_SEG = 1601; // STRING
            static const int TRANSACTION_ID_CODE = 1604; // STRING
            static const int PUBLICATION_VENUE = 1605; // STRING
            static const int PUBLICATION_TIME = 1606; // INT64
            static const int INSTRUMENT_CODE_TYPE = 1607; // STRING
            static const int EXECUTION_TIME = 1609; // INT64
            static const int MMT_MARKET_MECHANISM = 1610; // STRING
            static const int MMT_TRADING_MODE = 1611; // STRING
            static const int MMT_TRANSACTION_TYPE = 1612; // STRING
            static const int MMT_PUBLICATION_MODE = 1613; // STRING
            static const int MMT_DUPLICATIVE_INDICATOR = 1614; // STRING
            static const int LIS_CVOL = 1637; // INT
            static const int NEGOTIATED_CVOL = 1638; // INT
            static const int REFERENCE_CVOL = 1639; // INT
            static const int UNOFFICIAL_EXCH = 1650; // INT
            static const int VENDOR_TS = 1660; // EPOCH_NSEC
            static const int BID_TS = 1661; // EPOCH_NSEC
            static const int BID_CLOSE_TS = 1662; // EPOCH_NSEC
            static const int ASK_TS = 1663; // EPOCH_NSEC
            static const int ASK_CLOSE_TS = 1664; // EPOCH_NSEC
            static const int MID_TS = 1665; // EPOCH_NSEC
            static const int MID_CLOSE_TS = 1666; // EPOCH_NSEC
            static const int OPEN_TS = 1667; // EPOCH_NSEC
            static const int HIGH_TS = 1668; // EPOCH_NSEC
            static const int LOW_TS = 1669; // EPOCH_NSEC
            static const int UNOFFICIAL_TS = 1670; // EPOCH_NSEC
            static const int TRADED_TS = 1671; // EPOCH_NSEC
            static const int PREMKT_TS = 1672; // EPOCH_NSEC
            static const int POSTMKT_TS = 1673; // EPOCH_NSEC
            static const int LAST_TS = 1674; // EPOCH_NSEC
            static const int PREV_CLOSE_TS = 1675; // EPOCH_NSEC
            static const int CLOSE_TS = 1676; // EPOCH_NSEC
            static const int YTD_HIGH = 1732; // DOUBLE
            static const int YTD_LOW = 1736; // DOUBLE
            static const int YTD_HIGH_DATE = 1740; // INT
            static const int YTD_LOW_DATE = 1741; // INT
            static const int OFF_HOUR_EXCH = 1742; // INT
            static const int PREMKT_EXCH = 1743; // INT
            static const int POSTMKT_EXCH = 1744; // INT
            static const int OPT_DELIVERABLES = 1745; // STRING
            static const int UNDERLYING_EXCHANGE = 1746; // STRING
            static const int RT_PE_RATIO = 1747; // DOUBLE
            static const int RT_MARKET_CAP = 1748; // DOUBLE
            static const int ANNUAL_CAP_GAINS = 1749; // DOUBLE
            static const int MESSAGE_TYPE = 1750; // CHAR
            static const int RECORD_LAYOUT = 1804; // INT
            static const int BUY_ID = 1820; // STRING
            static const int SELL_ID = 1824; // STRING
            static const int PREMKT_VOL = 1832; // INT
            static const int PREMKT_CVOL = 1836; // INT
            static const int POSTMKT_VOL = 1860; // INT
            static const int POSTMKT_CVOL = 1864; // INT
            static const int POSTMKT_NET_CHANGE = 1881; // DOUBLE
            static const int POSTMKT_PERCENT_CHANGE = 1882; // DOUBLE
            static const int FINANCIAL_STATUS = 1896; // INT
            static const int POSTMKT_PRICE = 2029; // DOUBLE
            static const int TRUE_ISO_CODE = 2082; // STRING
            static const int SECURITY_STATUS = 2800; // INT
            static const int PRICING_METHOD = 3007; // INT
            static const int SUBSIDIZED_SEVEN_DAY_YIELD = 10052; // DOUBLE
            static const int SECURITY_TYPE = 13129; // STRING
            static const int MARKET_MAKER_ID = 14000; // STRING
            static const int MM_STAT_BITMASK = 14003; // INT
            static const int DELTA = 2620; // DOUBLE
            static const int GAMMA = 2621; // DOUBLE
            static const int VEGA = 2622; // DOUBLE
            static const int THETA = 2623; // DOUBLE
            static const int RHO = 2624; // DOUBLE
            //! \}
        };

    } // namespace FactSet
} // namespace Datafeed
#endif
