#ifndef __MD_LIB_MSGFIELDS_H__
#define __MD_LIB_MSGFIELDS_H__

#include <string>
#include <MD/MD_DateTime.h>
#include <MD/MD_Message.h>
#include <MD/MD_sys_types.h>
#include <MD/MD_Types.h>

// Routines for handling the various types of message fields that can
// be packed / unpacked inside MsgTs or IterMaps.

namespace MD {
  namespace FIELDS {

    // Get the length of a serialized field in bytes.  Returns 0 if the
    // field is variable length (string and buffer).
    template <typename FieldType>
    size_t netSize(FieldType) {
      return sizeof(FieldType);
    }

    // Get the type id of a message field.  Lets you say
    // typeId<float>() instead of MD::DATATYPES::FLOAT, and lets you
    // (potentially) do some more work at compile time, instead of
    // runtime.
    template <typename FieldType>
    MD::DATATYPES::TypeID typeId();


    // Definitions of the above functions

    template<>
    inline size_t netSize (MD::MD_Message::String data) {
      return data.size + 1;
    }

    template<>
    inline size_t netSize (MD::MD_Message::Buffer data) {
      return data.size;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <char>() {
      return MD::DATATYPES::CHAR;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <int8_t>() {
      return MD::DATATYPES::INT;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <int16_t>() {
      return MD::DATATYPES::INT;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <int32_t>() {
      return MD::DATATYPES::INT;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <int64_t>() {
      return MD::DATATYPES::INT64;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <float>() {
      return MD::DATATYPES::FLOAT;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <double>() {
      return MD::DATATYPES::DOUBLE;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <MD::MD_Message::String>() {
      return MD::DATATYPES::STRING;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <MD::MD_Message::Buffer>() {
      return MD::DATATYPES::BUFFER;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <MD::MD_DateTime>() {
      return MD::DATATYPES::DATETIME;
    }

    template <>
    inline MD::DATATYPES::TypeID typeId <MD::MD_EpochNS>() {
      return MD::DATATYPES::EPOCH_NSEC;
    }
  }
}

#endif // __MD_LIB_MSGFIELDS_H__
